#
# spec file for package python-arrow
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without python2
Name:           python-arrow
Version:        0.13.1
Release:        2.1
Summary:        Better dates and times for Python
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/crsmithdev/arrow
Source:         https://files.pythonhosted.org/packages/source/a/arrow/arrow-%{version}.tar.gz
BuildRequires:  %{python_module chai}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module simplejson}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-python-dateutil
BuildArch:      noarch
%if %{with python2}
BuildRequires:  python-backports.functools_lru_cache
%endif
%ifpython2
Requires:       python-backports.functools_lru_cache
%endif
%python_subpackages

%description
Arrow is a Python library that offers a sensible, human-friendly
approach to creating, manipulating, formatting and converting dates,
times, and timestamps.  It implements and updates the datetime type,
plugging gaps in functionality, and provides an intelligent module
API that supports many common creation scenarios.  Simply put, it
helps you work with dates and times with fewer imports and a lot
less code.

Arrow is heavily inspired by moment.js and requests.

%prep
%setup -q -n arrow-%{version}
rm -rf arrow.egg-info

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} nosetests-%{$python_bin_suffix} -v

%files %{python_files}
%license LICENSE
%doc README.rst HISTORY.md
%dir %{python_sitelib}/arrow
%{python_sitelib}/arrow/*
%dir %{python_sitelib}/arrow-%{version}-py*.egg-info
%{python_sitelib}/arrow-%{version}-py*.egg-info

%changelog
* Wed Mar  6 2019 tchvatal@suse.com
- Update to 0.13.1:
  * Support for python3.7
- Remove merged patch arrow-py37.patch
* Tue Jan 22 2019 tchvatal@suse.com
- Add patch to work with python 3.7:
  * arrow-py37.patch
* Sun Jan 20 2019 arun@gmx.de
- specfile:
  * update copyright year
  * be more specific in %%files section
  * require pytz
- update to version 0.13.0:
  * [NEW] Added support for Python 3.6.
  * [CHANGE] Drop support for Python 2.6/3.3.
  * [CHANGE] Return generator instead of list for Arrow.range(),
    Arrow.span_range() and Arrow.interval().
  * [FIX] Make arrow.get() work with str & tzinfo combo.
  * [FIX] Make sure special RegEx characters are escaped in format
    string.
  * [NEW] Added support for ZZZ when formatting.
  * [FIX] Stop using datetime.utcnow() in internals, use
    datetime.now(UTC) instead.
  * [FIX] Return NotImplemented instead of TypeError in arrow math
    internals.
  * [NEW] Added Estonian Locale.
  * [FIX] Small fixes to Greek locale.
  * [FIX] TagalogLocale improvements.
  * [FIX] Added test requirements to setup.
  * [FIX] Improve docs for get, now and utcnow methods.
  * [FIX] Correct typo in depreciation warning.
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Tue Feb 20 2018 arun@gmx.de
- specfile:
  * also require python-backports.functools_lru_cache during
    installation
* Sat Feb 17 2018 arun@gmx.de
- specfile:
  * update copyright year
  * require python-backports.functools_lru_cache for python2
- update to version 0.12.1:
  * Allow wheels to determine the required dependencies
  * Makes the only_distance paramter value equivalent to value given
    to function when granularity paramter is also provided by user
- changes from version 0.12.0:
  * [FIX] Compatibility fix for Python 2.x
- changes from version 0.11.0:
  * [FIX] Fix grammar of ArabicLocale
  * [NEW] Add Nepali Locale
  * [FIX] Fix month name + rename AustriaLocale -> AustrianLocale
  * [FIX] Fix typo in Basque Locale
  * [FIX] Fix grammar in PortugueseBrazilian locale
  * [FIX] Remove pip --user-mirrors flag
  * [NEW] Add Indonesian Locale
* Sat Jul 15 2017 aloisio@gmx.com
- Update to 0.10.0 (see HISTORY.md)
- Converted to singlespec
* Fri Feb 26 2016 tbechtold@suse.com
- Require python-python-dateutil. package was renamed
* Wed Aug  6 2014 toddrme2178@gmail.com
- Initial version
